@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.7.5
+;; Package-Version: 1.7.6
 ;; Package-Requires: ((emacs "26.1") (compat "30.0.1.0"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -225,7 +225,8 @@ This variable has to be set before `no-littering' is loaded.")
     (setq dap-breakpoints-file             (var "dap/breakpoints.el"))
     (setq dap-java-test-runner             (var "lsp-java/eclipse.jdt.ls/test-runner/junit-platform-console-standalone.jar"))
     (setq dap-utils-extension-path         (var "dap/extensions/"))
-    (setq dape-adapter-dir                 (var "dape-adapters/"))
+    (setq dape-adapter-dir                 (var "dape/adapters/"))
+    (setq dape-default-breakpoints-file    (var "dape/breakpoints.eld"))
     (setq debbugs-gnu-persistency-file     (var "debbugs.el"))
     (setq detached-db-directory            (var "detached/db/"))
     (setq detached-session-directory       (var "detached/sessions/"))
@@ -307,6 +308,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-caldav-save-directory        (var "org/caldav/save"))
     (setq org-gcal-dir                     (var "org/gcal/"))
     (setq org-journal-cache-file           (var "org/journal-cache.el"))
+    (setq org-node-data-dir                (var "org/node/"))
     (setq org-node-fakeroam-data-dir       (var "org/node-fakeroam/"))
     (setq org-recent-headings-save-file    (var "org/recent-headings.el"))
     (setq org-registry-file                (var "org/registry.el"))
